ActivateSession

Struct ActivateSession 

pub struct ActivateSession { /* private fields */ }
Sends an ActivateSessionRequest to the server to activate the session tied to the secure channel.

See OPC UA Part 4 - Services 5.6.3 for complete description of the service and error responses.

Note: Avoid calling this on sessions managed by the Session type. Session activation is handled automatically as part of connect/reconnect logic.

Implementations

Source

impl ActivateSession

pub fn diagnostics(self, bits: DiagnosticBits) -> Self

Set requested diagnostic bits.

pub fn timeout(self, timeout: Duration) -> Self

Set the timeout for this request. Defaults to session timeout.

pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self

Set the audit entry ID for the request.

pub fn header(&self) -> &RequestHeader

Get the request header.

Source

impl ActivateSession

pub fn new_manual( endpoint: EndpointDescription, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self

Create a new ActivateSession request.

pub fn identity_token(self, identity_token: IdentityToken) -> Self

Set the identity token.

pub fn private_key(self, private_key: PKey<RsaPrivateKey>) -> Self

Set the client private key.

pub fn locale_ids(self, locale_ids: Vec<UAString>) -> Self

Set the requested list of locales.

pub fn locale_id(self, locale_id: impl Into<UAString>) -> Self

Add a requested locale with the given ID.

pub fn client_software_certificates( self, certificates: Vec<SignedSoftwareCertificate>, ) -> Self

Set the client software certificates.

pub fn client_software_certificate( self, certificate: SignedSoftwareCertificate, ) -> Self

Add a client software certificate.