pub struct AddNodes { /* private fields */ }Expand description
Add nodes by sending a AddNodesRequest to the server.
See OPC UA Part 4 - Services 5.7.2 for complete description of the service and error responses.
Implementations
Sourceimpl AddNodes
impl AddNodes
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl AddNodes
impl AddNodes
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the AddNodes service, setting header parameters manually.
Sourcepub fn nodes_to_add(self, nodes_to_add: Vec<AddNodesItem>) -> Self
pub fn nodes_to_add(self, nodes_to_add: Vec<AddNodesItem>) -> Self
Set nodes to add, overwriting any that were set previously.
Sourcepub fn node(self, node: impl Into<AddNodesItem>) -> Self
pub fn node(self, node: impl Into<AddNodesItem>) -> Self
Add a node to create.