pub struct Call { /* private fields */ }Expand description
Calls a list of methods on the server by sending a CallRequest to the server.
See OPC UA Part 4 - Services 5.11.2 for complete description of the service and error responses.
Implementations
Sourceimpl Call
impl Call
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl Call
impl Call
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the Call service, setting header parameters manually.
Sourcepub fn methods_to_call(self, methods: Vec<CallMethodRequest>) -> Self
pub fn methods_to_call(self, methods: Vec<CallMethodRequest>) -> Self
Set the list of methods to call.
Sourcepub fn method(self, method: impl Into<CallMethodRequest>) -> Self
pub fn method(self, method: impl Into<CallMethodRequest>) -> Self
Add a method to call.