CreateMonitoredItems

Struct CreateMonitoredItems 

pub struct CreateMonitoredItems<'a> { /* private fields */ }
Creates monitored items on a subscription by sending a CreateMonitoredItemsRequest to the server.

See OPC UA Part 4 - Services 5.12.2 for complete description of the service and error responses.

Implementations

Source

impl<'a> CreateMonitoredItems<'a>

pub fn diagnostics(self, bits: DiagnosticBits) -> Self

Set requested diagnostic bits.

pub fn timeout(self, timeout: Duration) -> Self

Set the timeout for this request. Defaults to session timeout.

pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self

Set the audit entry ID for the request.

pub fn header(&self) -> &RequestHeader

Get the request header.

Source

impl<'a> CreateMonitoredItems<'a>

pub fn new(subscription_id: u32, session: &'a Session) -> Self

Construct a new call to the CreateMonitoredItems service.

pub fn new_manual( subscription_id: u32, monitored_item_handle: &'a AtomicHandle, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self

Construct a new call to the CreateMonitoredItems service, setting header parameters manually.

pub fn timestamps_to_return( self, timestamps_to_return: TimestampsToReturn, ) -> Self

An enumeration that specifies the timestamp Attributes to be transmitted for each MonitoredItem.

pub fn items_to_create( self, items_to_create: Vec<MonitoredItemCreateRequest>, ) -> Self

Set the monitored items to create, overwriting any that were added previously.

pub fn item(self, item: MonitoredItemCreateRequest) -> Self

Add a monitored item to create.

pub fn value( self, node_id: NodeId, sampling_interval: f64, queue_size: u32, ) -> Self

Add a monitored item to create, subscribing to values on node_id with the given sampling_interval and queue_size.