pub struct DeleteReferences { /* private fields */ }Expand description
Delete references by sending a DeleteReferencesRequest to the server.
See OPC UA Part 4 - Services 5.7.5 for complete description of the service and error responses.
Implementations
Sourceimpl DeleteReferences
impl DeleteReferences
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl DeleteReferences
impl DeleteReferences
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the DeleteReferences service, setting header parameters manually.
Sourcepub fn references_to_delete(
self,
references_to_delete: Vec<DeleteReferencesItem>,
) -> Self
pub fn references_to_delete( self, references_to_delete: Vec<DeleteReferencesItem>, ) -> Self
Set nodes to delete, overwriting any that were set previously.
Sourcepub fn reference(self, reference: impl Into<DeleteReferencesItem>) -> Self
pub fn reference(self, reference: impl Into<DeleteReferencesItem>) -> Self
Add a reference to delete.