pub struct HistoryRead { /* private fields */ }Expand description
Reads historical values or events of one or more nodes. The caller is expected to provide a HistoryReadAction enum which must be one of the following:
See OPC UA Part 4 - Services 5.10.3 for complete description of the service and error responses.
Implementations
Sourceimpl HistoryRead
impl HistoryRead
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl HistoryRead
impl HistoryRead
Sourcepub fn new(details: HistoryReadAction, session: &Session) -> Self
pub fn new(details: HistoryReadAction, session: &Session) -> Self
Create a new HistoryRead request.
Sourcepub fn new_manual(
details: HistoryReadAction,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( details: HistoryReadAction, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the HistoryRead service, setting header parameters manually.
Sourcepub fn timestamps_to_return(self, timestamps: TimestampsToReturn) -> Self
pub fn timestamps_to_return(self, timestamps: TimestampsToReturn) -> Self
Set timestamps to return.
Sourcepub fn release_continuation_points(
self,
release_continuation_points: bool,
) -> Self
pub fn release_continuation_points( self, release_continuation_points: bool, ) -> Self
Set release continuation points. Default is false, if this is true, continuation points will be freed and the request will return without reading any history.
Sourcepub fn nodes_to_read(self, nodes_to_read: Vec<HistoryReadValueId>) -> Self
pub fn nodes_to_read(self, nodes_to_read: Vec<HistoryReadValueId>) -> Self
Set nodes to read, overwriting any that were set previously.
Sourcepub fn node(self, node: HistoryReadValueId) -> Self
pub fn node(self, node: HistoryReadValueId) -> Self
Add a node to read.