pub struct HistoryUpdate { /* private fields */ }Expand description
Updates historical values. The caller is expected to provide one or more history update operations in a slice of HistoryUpdateAction enums which are one of the following:
UpdateDataDetailsUpdateStructureDataDetailsUpdateEventDetailsDeleteRawModifiedDetailsDeleteAtTimeDetailsDeleteEventDetails
See OPC UA Part 4 - Services 5.10.5 for complete description of the service and error responses.
Implementations
Sourceimpl HistoryUpdate
impl HistoryUpdate
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl HistoryUpdate
impl HistoryUpdate
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the HistoryUpdate service, setting header parameters manually.
Sourcepub fn details(self, details: Vec<HistoryUpdateAction>) -> Self
pub fn details(self, details: Vec<HistoryUpdateAction>) -> Self
Set the history update actions to perform.
Sourcepub fn action(self, action: impl Into<HistoryUpdateAction>) -> Self
pub fn action(self, action: impl Into<HistoryUpdateAction>) -> Self
Add a history update action to the list.