pub struct ModifyMonitoredItems { /* private fields */ }Expand description
Modifies monitored items on a subscription by sending a ModifyMonitoredItemsRequest to the server.
See OPC UA Part 4 - Services 5.12.3 for complete description of the service and error responses.
Implementations
Sourceimpl ModifyMonitoredItems
impl ModifyMonitoredItems
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl ModifyMonitoredItems
impl ModifyMonitoredItems
Sourcepub fn new(subscription_id: u32, session: &Session) -> Self
pub fn new(subscription_id: u32, session: &Session) -> Self
Construct a new call to the ModifyMonitoredItems service.
Sourcepub fn new_manual(
subscription_id: u32,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( subscription_id: u32, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the ModifyMonitoredItems service, setting header parameters manually.
Sourcepub fn timestamps_to_return(
self,
timestamps_to_return: TimestampsToReturn,
) -> Self
pub fn timestamps_to_return( self, timestamps_to_return: TimestampsToReturn, ) -> Self
An enumeration that specifies the timestamp Attributes to be transmitted for each MonitoredItem.
Sourcepub fn items_to_modify(
self,
items_to_modify: Vec<MonitoredItemModifyRequest>,
) -> Self
pub fn items_to_modify( self, items_to_modify: Vec<MonitoredItemModifyRequest>, ) -> Self
Set the monitored items to modify, overwriting any that were added previously.
Sourcepub fn item(self, item: MonitoredItemModifyRequest) -> Self
pub fn item(self, item: MonitoredItemModifyRequest) -> Self
Add a monitored item to modify.