pub struct ModifySubscription { /* private fields */ }Expand description
Modifies a subscription by sending a ModifySubscriptionRequest to the server.
See OPC UA Part 4 - Services 5.13.3 for complete description of the service and error responses.
Implementations
Sourceimpl ModifySubscription
impl ModifySubscription
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl ModifySubscription
impl ModifySubscription
Sourcepub fn new(subscription_id: u32, session: &Session) -> Self
pub fn new(subscription_id: u32, session: &Session) -> Self
Construct a new call to the ModifySubscription service.
Sourcepub fn new_manual(
subscription_id: u32,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( subscription_id: u32, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the ModifySubscription service, setting header parameters manually.
Sourcepub fn publishing_interval(self, interval: Duration) -> Self
pub fn publishing_interval(self, interval: Duration) -> Self
The requested publishing interval defines the cyclic rate that the Subscription is being requested to return Notifications to the Client. This interval is expressed in milliseconds. This interval is represented by the publishing timer in the Subscription state table. The negotiated value for this parameter returned in the response is used as the default sampling interval for MonitoredItems assigned to this Subscription. If the requested value is 0 or negative, the server shall revise with the fastest supported publishing interval in milliseconds.
Sourcepub fn max_lifetime_count(self, lifetime_count: u32) -> Self
pub fn max_lifetime_count(self, lifetime_count: u32) -> Self
Requested lifetime count. The lifetime count shall be a minimum of three times the keep keep-alive count. When the publishing timer has expired this number of times without a Publish request being available to send a NotificationMessage, then the Subscription shall be deleted by the Server.
Sourcepub fn max_keep_alive_count(self, keep_alive_count: u32) -> Self
pub fn max_keep_alive_count(self, keep_alive_count: u32) -> Self
Requested maximum keep-alive count. When the publishing timer has expired this number of times without requiring any NotificationMessage to be sent, the Subscription sends a keep-alive Message to the Client. The negotiated value for this parameter is returned in the response. If the requested value is 0, the server shall revise with the smallest supported keep-alive count.
Sourcepub fn max_notifications_per_publish(
self,
max_notifications_per_publish: u32,
) -> Self
pub fn max_notifications_per_publish( self, max_notifications_per_publish: u32, ) -> Self
The maximum number of notifications that the Client wishes to receive in a single Publish response. A value of zero indicates that there is no limit. The number of notifications per Publish is the sum of monitoredItems in the DataChangeNotification and events in the EventNotificationList.
Sourcepub fn priority(self, priority: u8) -> Self
pub fn priority(self, priority: u8) -> Self
Indicates the relative priority of the Subscription. When more than one Subscription needs to send Notifications, the Server should de-queue a Publish request to the Subscription with the highest priority number. For Subscriptions with equal priority the Server should de-queue Publish requests in a round-robin fashion.