pub struct RegisterNodes { /* private fields */ }Expand description
Register nodes on the server by sending a RegisterNodesRequest. The purpose of this
call is server-dependent but allows a client to ask a server to create nodes which are
otherwise expensive to set up or maintain, e.g. nodes attached to hardware.
See OPC UA Part 4 - Services 5.8.5 for complete description of the service and error responses.
Implementations
Sourceimpl RegisterNodes
impl RegisterNodes
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl RegisterNodes
impl RegisterNodes
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the RegisterNodes service, setting header parameters manually.
Sourcepub fn nodes_to_register(self, nodes_to_register: Vec<NodeId>) -> Self
pub fn nodes_to_register(self, nodes_to_register: Vec<NodeId>) -> Self
Set nodes to register, overwriting any that were set previously.
Sourcepub fn node_to_register(self, node_to_register: impl Into<NodeId>) -> Self
pub fn node_to_register(self, node_to_register: impl Into<NodeId>) -> Self
Add a node to the request.