pub struct SetMonitoringMode { /* private fields */ }Expand description
Sets the monitoring mode on one or more monitored items by sending a SetMonitoringModeRequest
to the server.
See OPC UA Part 4 - Services 5.12.4 for complete description of the service and error responses.
Implementations
Sourceimpl SetMonitoringMode
impl SetMonitoringMode
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl SetMonitoringMode
impl SetMonitoringMode
Sourcepub fn new(
subscription_id: u32,
monitoring_mode: MonitoringMode,
session: &Session,
) -> Self
pub fn new( subscription_id: u32, monitoring_mode: MonitoringMode, session: &Session, ) -> Self
Construct a new call to the SetMonitoringMode service.
Sourcepub fn new_manual(
subscription_id: u32,
monitoring_mode: MonitoringMode,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( subscription_id: u32, monitoring_mode: MonitoringMode, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the SetMonitoringMode service, setting header parameters manually.
Sourcepub fn monitored_item_ids(self, monitored_item_ids: Vec<u32>) -> Self
pub fn monitored_item_ids(self, monitored_item_ids: Vec<u32>) -> Self
Set the monitored items to modify, overwriting any that were added previously.