pub struct SetPublishingMode { /* private fields */ }Expand description
Changes the publishing mode of subscriptions by sending a SetPublishingModeRequest to the server.
See OPC UA Part 4 - Services 5.13.4 for complete description of the service and error responses.
Implementations
Sourceimpl SetPublishingMode
impl SetPublishingMode
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl SetPublishingMode
impl SetPublishingMode
Sourcepub fn new(publishing_enabled: bool, session: &Session) -> Self
pub fn new(publishing_enabled: bool, session: &Session) -> Self
Construct a new call to the SetPublishingMode service.
Sourcepub fn new_manual(
publishing_enabled: bool,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( publishing_enabled: bool, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the SetPublishingMode service, setting header parameters manually.
Sourcepub fn subscription_ids(self, subscription_ids: Vec<u32>) -> Self
pub fn subscription_ids(self, subscription_ids: Vec<u32>) -> Self
Set the subscription IDs to update, overwriting any that were added previously.
Sourcepub fn subscription(self, subscription_id: u32) -> Self
pub fn subscription(self, subscription_id: u32) -> Self
Add a subscription ID to update.