pub struct SetTriggering { /* private fields */ }Expand description
Sets a monitored item so it becomes the trigger that causes other monitored items to send
change events in the same update. Sends a SetTriggeringRequest to the server.
Note that items_to_remove is applied before items_to_add.
See OPC UA Part 4 - Services 5.12.5 for complete description of the service and error responses.
Implementations
Sourceimpl SetTriggering
impl SetTriggering
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl SetTriggering
impl SetTriggering
Sourcepub fn new(
subscription_id: u32,
triggering_item_id: u32,
session: &Session,
) -> Self
pub fn new( subscription_id: u32, triggering_item_id: u32, session: &Session, ) -> Self
Construct a new call to the SetTriggering service.
Sourcepub fn new_manual(
subscription_id: u32,
triggering_item_id: u32,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( subscription_id: u32, triggering_item_id: u32, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the SetTriggering service, setting header parameters manually.
Sourcepub fn links_to_add(self, links_to_add: Vec<u32>) -> Self
pub fn links_to_add(self, links_to_add: Vec<u32>) -> Self
Set the links to add, overwriting any that were added previously.
Sourcepub fn links_to_remove(self, links_to_remove: Vec<u32>) -> Self
pub fn links_to_remove(self, links_to_remove: Vec<u32>) -> Self
Set the links to add, overwriting any that were added previously.
Sourcepub fn remove_link(self, item: u32) -> Self
pub fn remove_link(self, item: u32) -> Self
Add a new trigger to remove.