TransferSubscriptions

Struct TransferSubscriptions 

pub struct TransferSubscriptions { /* private fields */ }
Transfers Subscriptions and their MonitoredItems from one Session to another. For example, a Client may need to reopen a Session and then transfer its Subscriptions to that Session. It may also be used by one Client to take over a Subscription from another Client by transferring the Subscription to its Session.

Note that if you call this manually, you will need to register the subscriptions in the subscription state (Session::subscription_state) in order to receive notifications.

See OPC UA Part 4 - Services 5.13.7 for complete description of the service and error responses.

Implementations

Source

impl TransferSubscriptions

pub fn diagnostics(self, bits: DiagnosticBits) -> Self

Set requested diagnostic bits.

pub fn timeout(self, timeout: Duration) -> Self

Set the timeout for this request. Defaults to session timeout.

pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self

Set the audit entry ID for the request.

pub fn header(&self) -> &RequestHeader

Get the request header.

Source

impl TransferSubscriptions

pub fn new(session: &Session) -> Self

Construct a new call to the TransferSubscriptions service.

pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self

Construct a new call to the TransferSubscriptions service, setting header parameters manually.

pub fn send_initial_values(self, send_initial_values: bool) -> Self

A boolean parameter with the following values - true the first publish response shall contain the current values of all monitored items in the subscription, false, the first publish response shall contain only the value changes since the last publish response was sent.

pub fn subscription_ids(self, subscription_ids: Vec<u32>) -> Self

Set the subscription IDs to transfer, overwriting any that were added previously.

pub fn subscription(self, subscription_id: u32) -> Self

Add a subscription ID to transfer.