IssuedTokenSource

Trait IssuedTokenSource 

pub trait IssuedTokenSource: Send + Sync {
    // Required method
    fn get_issued_token<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<ByteString, Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Source for an issued token. Since each re-authentication when using issued tokens may require a new token.

Required Methods

fn get_issued_token<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ByteString, Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get a valid issued token. This may be a cached token, or a new one if the cache is empty or expired.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IssuedTokenSource for ByteString

Source

fn get_issued_token<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ByteString, Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Implementors