SecureChannelEventLoop

Struct SecureChannelEventLoop 

pub struct SecureChannelEventLoop<T> { /* private fields */ }
Event loop for a secure channel. This must be polled to make progress.

Implementations

Source

impl<T: Transport + Send + Sync + 'static> SecureChannelEventLoop<T>

pub async fn poll(&mut self) -> TransportPollResult

Poll the channel, processing any pending incoming or outgoing messages and returning the action that was taken.

pub fn connected_url(&self) -> &str

Get the URL of the connected server. This was either the URL used to establish the connection, or the URL reported by the server in ReverseHello.