pub struct ActivateSession { /* private fields */ }Expand description
Sends an ActivateSessionRequest to the server to activate the session tied to
the secure channel.
See OPC UA Part 4 - Services 5.6.3 for complete description of the service and error responses.
Note: Avoid calling this on sessions managed by the Session type. Session activation
is handled automatically as part of connect/reconnect logic.
Implementations
Sourceimpl ActivateSession
impl ActivateSession
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl ActivateSession
impl ActivateSession
Sourcepub fn new_manual(
endpoint: EndpointDescription,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( endpoint: EndpointDescription, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Create a new ActivateSession request.
Sourcepub fn identity_token(self, identity_token: IdentityToken) -> Self
pub fn identity_token(self, identity_token: IdentityToken) -> Self
Set the identity token.
Sourcepub fn private_key(self, private_key: PKey<RsaPrivateKey>) -> Self
pub fn private_key(self, private_key: PKey<RsaPrivateKey>) -> Self
Set the client private key.
Sourcepub fn locale_ids(self, locale_ids: Vec<UAString>) -> Self
pub fn locale_ids(self, locale_ids: Vec<UAString>) -> Self
Set the requested list of locales.
Sourcepub fn locale_id(self, locale_id: impl Into<UAString>) -> Self
pub fn locale_id(self, locale_id: impl Into<UAString>) -> Self
Add a requested locale with the given ID.
Sourcepub fn client_software_certificates(
self,
certificates: Vec<SignedSoftwareCertificate>,
) -> Self
pub fn client_software_certificates( self, certificates: Vec<SignedSoftwareCertificate>, ) -> Self
Set the client software certificates.
Sourcepub fn client_software_certificate(
self,
certificate: SignedSoftwareCertificate,
) -> Self
pub fn client_software_certificate( self, certificate: SignedSoftwareCertificate, ) -> Self
Add a client software certificate.