pub struct CloseSession { /* private fields */ }Expand description
Close the session by sending a CloseSessionRequest to the server.
Note: Avoid using this on an session managed by the Session type,
instead call Session::disconnect.
Implementations
Sourceimpl CloseSession
impl CloseSession
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl CloseSession
impl CloseSession
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Create a new CloseSession request.
Sourcepub fn delete_subscriptions(self, delete_subscriptions: bool) -> Self
pub fn delete_subscriptions(self, delete_subscriptions: bool) -> Self
Set DeleteSubscriptions, indicating to the server whether it should
delete subscriptions immediately or wait for them to expire.