pub struct CreateMonitoredItems<'a> { /* private fields */ }Expand description
Creates monitored items on a subscription by sending a CreateMonitoredItemsRequest to the server.
See OPC UA Part 4 - Services 5.12.2 for complete description of the service and error responses.
Implementations
Sourceimpl<'a> CreateMonitoredItems<'a>
impl<'a> CreateMonitoredItems<'a>
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl<'a> CreateMonitoredItems<'a>
impl<'a> CreateMonitoredItems<'a>
Sourcepub fn new(subscription_id: u32, session: &'a Session) -> Self
pub fn new(subscription_id: u32, session: &'a Session) -> Self
Construct a new call to the CreateMonitoredItems service.
Sourcepub fn new_manual(
subscription_id: u32,
monitored_item_handle: &'a AtomicHandle,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( subscription_id: u32, monitored_item_handle: &'a AtomicHandle, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Construct a new call to the CreateMonitoredItems service, setting header parameters manually.
Sourcepub fn timestamps_to_return(
self,
timestamps_to_return: TimestampsToReturn,
) -> Self
pub fn timestamps_to_return( self, timestamps_to_return: TimestampsToReturn, ) -> Self
An enumeration that specifies the timestamp Attributes to be transmitted for each MonitoredItem.
Sourcepub fn items_to_create(
self,
items_to_create: Vec<MonitoredItemCreateRequest>,
) -> Self
pub fn items_to_create( self, items_to_create: Vec<MonitoredItemCreateRequest>, ) -> Self
Set the monitored items to create, overwriting any that were added previously.
Sourcepub fn item(self, item: MonitoredItemCreateRequest) -> Self
pub fn item(self, item: MonitoredItemCreateRequest) -> Self
Add a monitored item to create.