pub struct CreateSession<'a> { /* private fields */ }Expand description
Sends a CreateSessionRequest to the server, returning the session id of the created
session. Internally, the session will store the authentication token which is used for requests
subsequent to this call.
See OPC UA Part 4 - Services 5.6.2 for complete description of the service and error responses.
Note that in order to use the session you will need to store the auth token and use that in subsequent requests.
Note: Avoid calling this on sessions managed by the Session type. Session creation
is handled automatically as part of connect/reconnect logic.
Implementations
Sourceimpl<'a> CreateSession<'a>
impl<'a> CreateSession<'a>
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Self
pub fn diagnostics(self, bits: DiagnosticBits) -> Self
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Self
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl<'a> CreateSession<'a>
impl<'a> CreateSession<'a>
Sourcepub fn new_manual(
certificate_store: &'a RwLock<CertificateStore>,
endpoint: &'a EndpointDescription,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: IntegerId,
) -> Self
pub fn new_manual( certificate_store: &'a RwLock<CertificateStore>, endpoint: &'a EndpointDescription, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: IntegerId, ) -> Self
Create a new CreateSession request with the given data.
Sourcepub fn client_description(self, desc: impl Into<ApplicationDescription>) -> Self
pub fn client_description(self, desc: impl Into<ApplicationDescription>) -> Self
Set the client description.
Sourcepub fn server_uri(self, server_uri: impl Into<UAString>) -> Self
pub fn server_uri(self, server_uri: impl Into<UAString>) -> Self
Set the server URI.
Sourcepub fn endpoint_url(self, endpoint_url: impl Into<UAString>) -> Self
pub fn endpoint_url(self, endpoint_url: impl Into<UAString>) -> Self
Set the target endpoint URL.
Sourcepub fn session_name(self, session_name: impl Into<UAString>) -> Self
pub fn session_name(self, session_name: impl Into<UAString>) -> Self
Set the session name.
Sourcepub fn client_certificate(self, client_certificate: X509) -> Self
pub fn client_certificate(self, client_certificate: X509) -> Self
Set the client certificate.
Sourcepub fn client_cert_from_store(
self,
certificate_store: &RwLock<CertificateStore>,
) -> Self
pub fn client_cert_from_store( self, certificate_store: &RwLock<CertificateStore>, ) -> Self
Load the client certificate from the certificate store.
Sourcepub fn session_timeout(self, session_timeout: f64) -> Self
pub fn session_timeout(self, session_timeout: f64) -> Self
Set the timeout for the session.
Sourcepub fn max_response_message_size(self, max_response_message_size: u32) -> Self
pub fn max_response_message_size(self, max_response_message_size: u32) -> Self
Set the requested maximum response message size.
Sourcepub fn nonce_length(self, nonce_length: usize) -> Self
pub fn nonce_length(self, nonce_length: usize) -> Self
Set the length of the client nonce used to generate this request.