pub struct SecureChannelEventLoop<T> { /* private fields */ }Expand description
Event loop for a secure channel. This must be polled to make progress.
Implementations
Sourceimpl<T: Transport + Send + Sync + 'static> SecureChannelEventLoop<T>
impl<T: Transport + Send + Sync + 'static> SecureChannelEventLoop<T>
Sourcepub async fn poll(&mut self) -> TransportPollResult
pub async fn poll(&mut self) -> TransportPollResult
Poll the channel, processing any pending incoming or outgoing messages and returning the action that was taken.
Sourcepub fn connected_url(&self) -> &str
pub fn connected_url(&self) -> &str
Get the URL of the connected server. This was either the URL used to establish the connection, or the URL reported by the server in ReverseHello.